import java.util.*;

public class TronChange {

	static double TINY = 1E-10;			// a small number, but not too small -- otherwise correct answers may be discarded because of floating point errors

    static boolean DEBUG = false;

    static int TOO_BIG = 10000000;

    static int num_solutions = 0;
	
	/** 
	 *  main program
	 */
	public static void main(String[] args) throws Exception {
										// read input
		Scanner scanner = new Scanner(System.in);
        int numCases = scanner.nextInt();

        for(int t = 0; t < numCases; t++) {
            int n = scanner.nextInt();		// input number of reciprocals

            num_solutions = 0;

            if (n <= 0) {
                System.out.println("Error: Need at least 1 coin");
                System.exit(0);
            }
            int r = scanner.nextInt();		// input number of repetitions
            if (r < 0) {
                System.out.println("Error: Repetition count must be nonnegative");
                System.exit(0);
            }

            int f = scanner.nextInt(); 		// number of forbidden values
            int[] F = new int[f];			// list of forbidden values
            for (int i = 0; i < f; i++) {	// input forbidden
                F[i] = scanner.nextInt();
                if (F[i] <= 0) {
                    System.out.println("Error: Forbidden values must be positive");
                    System.exit(0);
                }
            }

            // print input summary
            System.out.print("Case " + (t+1) + " " + ": Number of coins = " + n + "; Repetitions = " + r + "; Forbidden = [");
            if(F.length != 0) {
                System.out.print(F[0]);
                for (int i = 1; i < F.length; i++)
                    System.out.print(" " + F[i]);
            }
            System.out.println("]");

            makeChange(n, r, F); // solve

            // print output summary
            if (num_solutions == 0) {
                System.out.println("No solutions found");
            } else {		
                System.out.println(num_solutions + " solutions found");
            }
        }
	}
	
    /* Use this to print one solution. */
    private static void printOneOutput(int[] coins) {
        double sum = 0, remainder = 1.0;

        num_solutions++;

        for(int i = 0; i < coins.length - 1; i++) {
            System.out.print(coins[i] + " ");

            sum += 1/((double) coins[i]);
            remainder -= 1/((double) coins[i]);
        }

        sum += 1/((double) coins[coins.length - 1]);
        remainder -= 1/((double) coins[coins.length - 1]);

        if(DEBUG) 
            System.out.println(coins[coins.length - 1] + " SUMS UP TO " + sum + " REMAINDER = " + remainder);
        else
            System.out.println(coins[coins.length - 1]);
    }

    /* What follows are three helper subroutines and one main subroutine that verifies whether
     * a particular set of coins is actually a correct answer. 
     *
     * We do this by doing modulo arithmatic, and using the Chinese Remainder Theorem. */
    private static int multiply_mod(int a, int b, int mod) {
        return (a%mod) * (b%mod) % mod;
    }

    private static int compute_product_mod(int[] ar, int ignore, int mod) {
        int ret = 1;
        for(int i = 0; i < ar.length; i++) 
            if(i != ignore) 
                ret = multiply_mod(ret, ar[i], mod);
        return ret;
    }

    private static boolean verify(int[] ar, int mod) {
        int lhs = compute_product_mod(ar, -1, mod);
        int rhs = 0;
        for(int i = 0; i < ar.length; i++) 
            rhs = (rhs + compute_product_mod(ar, i, mod)) % mod;
        return (lhs == rhs);
    }

    private static boolean verify(int[] ar) {
        int[] primes = {2, 3, 5, 7, 11, 13, 17, 19, 23, 29, 31, 37, 41, 43, 47, 53, 59, 61, 67, 71, 73, 79, 83, 89, 97, 101};

        for(int p : primes) {
            if(! verify(ar, p))
                return false;
        }
        return true;
    }

    /** Some helper routines. */
    private static boolean contains(int[] ar, int a) {
        for(int i : ar) 
            if(i == a) 
                return true;
        return false;
    }

    /* Given the current sum, what is the maximum value of m so that we can still make up the gap. */
    private static int max_m_allowed(double current_sum, int remaining_coins) {
        /* We need: current_sum + remaining_coins * 1/m  > 1 - TINY. That gives us:
         * if "m" is more than the following value, then it is not possible for remaining_coins to make up for it. */
        return (int) Math.floor(remaining_coins/(1 - current_sum - TINY));
    }

    /* Given the current sum and just one coin left, what is the smallest m so that we are not too far from 1. If we could do
     * exact floating point computation, we can just ask if there is an m that completes the solution, but since we can't
     * do that, we must do approximate checks. */
    private static int min_m_required(double current_sum) {
        /* We need: current_sum + 1/m  < 1 + TINY. That gives us: m > 1/(1 + TINY - current_sum). */
        return (int) Math.ceil(1 / (1 - current_sum + TINY));
    }

    /* The following implementation is a simple backtracking algorithm that keeps: 
     * the current state of the solution in "int[] coins", 
     * partial sums in "double[] q", 
     * and uses "index" to keep track of where we are. 
     *
     * At every point, we either add another entry to coins, or we backtrack.
     * During this process, we use the above two helper functions max_m_allowed and min_m_required to 
     * choose correct values of "m". If we were to check values of "m" one by one, it would take too long.
     *
     * Finally, after we have found an approximate partial solution, we use "verify()" to confirm the answer.
     * */
	private static void makeChange(
		int n,			// number of coins to use
		int r, 			// maximum number of repetitions per coin
		int[] F) 		// forbidden coins
	{

        int[] coins = new int[n];
        double[] q = new double[n+1]; // q[i] = sum of reciprocals from coins[0] to coins[i-1]
        q[0] = 0;
        int index = 0; // current position in the coins array
        int t = r; /* number of repetitions remaining. */
        int m = 1; // largest coin to use

        while(true) {
            if(DEBUG) System.out.println("index = " + index + ", m = " + m + ", q[index] = " + q[index]);
            if(DEBUG) {System.out.print("current state = "); printOneOutput(coins);}

            if(m > TOO_BIG) {
                // backtrack
                if(index == 0) 
                    return;
                index--; 
                t = r;
                m = (int) Math.max(coins[index]+1, min_m_required(q[index]));
            } else {
                if (index == coins.length) {
                    if (Math.abs(1 - q[index]) < TINY) {
                        if(verify(coins)) {
                            printOneOutput(coins);
                            if(DEBUG) System.out.println("one output done... " + q[index]);
                        } else {
                            if(DEBUG) System.out.print("INCORRECT: ");
                            if(DEBUG) printOneOutput(coins);
                        }
                    }

                    // backtrack
                    if(DEBUG) System.out.println("backtracking ...");
                    index--; 
                    t = r;
                    m = (int) Math.max(coins[index]+1, min_m_required(q[index]));

                    if(DEBUG) System.out.println("backtracking.. setting m to " + m);
                } else {							
                    double remaining = 1 - q[index];
                    if ( (remaining > TINY) && (m <= max_m_allowed(q[index], coins.length - index)) ) { // is solution still possible?

                        if(! contains(F, m) && (r == 0 || t > 0) ) {		// can we use 1/m?
                            coins[index] = m;
                            index++;
                            q[index] = q[index-1] + 1/((double)m);
                            t--;
                        } else {
                            m = (int) Math.max(m+1, min_m_required(q[index]));
                            t = r;
                            if(DEBUG) System.out.println("checking next value..");
                        }
                    } else {
                        // backtrack
                        if(index == 0) 
                            return;
                        index--; 
                        t = r;
                        m = (int) Math.max(coins[index]+1, min_m_required(q[index]));

                        if(DEBUG) System.out.println("backtracking..");
                    }
                }
            }
        }
	}
}
