import java.util.LinkedList;
import java.util.Queue;
import java.util.Scanner;

public class DiscArena {

	final static int MAXN = 1002;

	final static int INF = 1<<29;

    /* The following two are needed to run BFS. */
	static Queue<Integer> q = new LinkedList<Integer>(); 
	static int parent[] = new int[MAXN]; 

	/* Finds an augmenting path using BFS. Returns the increase on the amount of flow. */
	private static int increaseflow ( int[][] c, int s , int t) { 

        /* Re-initialize. */
		for (int i = 0; i < MAXN; i++)
			parent[i] = -1;
		while (q.size() > 0) 
            q.remove();

        /* Add the source to the queue. */
		q.offer(s); 
        parent[s] = s;

		while (q.size() > 0) {
			int v = q.remove() ;

			for (int i = 0; i < c.length; ++i){
				if ( (c[v][i] > 0) && (parent[i] == -1)) {
					parent[i]=v ;
					q.offer(i) ;
				}
			}

		}

		if (parent[t] == -1)
            return 0; // there is no path from the source to the sink -- we are done

        /* Find the edge with minimum weight in the path from s to t. */
		int neck=INF;
		for (int v = t ; v != s ; v = parent[v])
			if (neck > c[parent[v]][v])
				neck = c[parent[v]][v];

        /* Reduce the capacities of all edges on the path. Must increase the capacities on the "reverse" edges. */
		for (int v = t ; v != s ; v = parent[v]) {
			c [parent[v]] [v] -= neck ;
			c [v][ parent[v]] += neck ;
		}
		return neck ;
	}
	
	public static int solveDiscArena(int[] fames, int[][] prereqs) {
		
        /* ------------------- INSERT CODE HERE --------------------- */

        /* We will represent prerequisite structure as a directed graph, represented using an adjacent matrix. 
         * We will have two extra nodes, a source and a sink. */

        int n = fames.length;

        int c[][] = new int[n+2][n+2]; // Captures the "capacity" of each edge. Details below.
        
        for (int i = 0; i < n+2; i++)
            for (int j = 0; j < n+2; j++)
                c[i][j] = 0;

        /* Lets initialize c[][] and calculate the total sum of positive fame games. */
        int sumpos = 0;

        for (int i = 0; i < n; i++){
            if (fames[i] > 0) {
                /* If fames[i] > 0, we will add an edge from the "source" to it. We use the n'th entry for the source. */
                c[n][i] = fames[i];
                sumpos += fames[i];
            } else {
                /* If fames[i] < 0, we will add an edge from it to the "sink" (index = n+1) */
                c[i][n+1] = -fames[i];
            }

            /* For every prerequisite, we will add a backwards edge from a node to the prerequisite. */

            for (int j = 0; j < prereqs[i].length; j++)
					c[i][prereqs[i][j] - 1] = INF;
        } 

        /* Now the absolute maximum fame attainable is "sumpos", where we win all the positive fame games. However, 
         * because of the prerequisite structure, this may not be possible. Hence, we will try to find the total 
         * loss because of having to play prerequisites. 
         *
         * Consider a "edge cut" that separates the nodes "n" and "n+1" in the directed graph above -- i.e., a 
         * set of edges after deleting which there is no path from "n" to "n+1".
         *
         * We can show that the minimum loss by having to play games with negative fame is exactly the size
         * of the minimum weight cut, where the weight of a cut is the sum of the weights of edges that were cut.
         *
         * Hence, we first find the minimum cut, and then subtract it from sumpos.
         *
         * The rest of the code is an implementation of the standard 'augmenting path' algortihm for finding maximum flow,
         * which is equivalent to finding a minimum cut. The algorithm terminates in reasonable time if the edge weights
         * are all integers, which is true in this case. 
         * */

		int flow = 0, tmp;

        while ( (tmp = increaseflow (c, n , n+1)) > 0)
            flow += tmp;

        return sumpos - flow;

        /* -------------------- END OF INSERTION --------------------*/
        // return -1;
	}

    public static void main(String[] args) {
        Scanner sc = new Scanner(System.in);

        int numCases = sc.nextInt();

        for(int i = 0; i < numCases; i++) 
        {
            int numberOfGames = sc.nextInt();

            int[] fames = new int[numberOfGames];
            int[][] prereqs = new int[numberOfGames][];

            for(int j = 0; j < numberOfGames; j++) {
                fames[j] = sc.nextInt();
                prereqs[j] = new int[sc.nextInt()];

                for(int k = 0; k < prereqs[j].length; k++)
                    prereqs[j][k] = sc.nextInt();
            }

            System.out.println("Case " + (i+1) + ": Maximum attainable fame = " + solveDiscArena(fames, prereqs));
        }

    }
}
